Autosize - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

# Autosize

The autosize element will automatically adjust the textarea height and make it easier for users to follow as they type.

To be able to use the autosize in your application you will need to install the autosize dependency with `npm install autosize`.

## Default markup

Add the autosize element to your input to make it automatically adjust to the length of a text as a user types it.

    <label class="form-label">Autosize example</label>
    <textarea class="form-control" data-bs-toggle="autosize" placeholder="Type something…"></textarea>